from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x08\x00\x55\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x9b\x08\x00\x00\x00\x00\x00\x18\x16\xfc\xb4\x7c\x30\xf4\xe1\x51\xb0\x35\x60\x75\xcb\x84\x81\xe8\x00\x00\x00\x00\x00\x00\x00\x00\xda\x71\xe2\xaf\xb0\xb1\x5a\xda\x61\xe4\xad\x65\x88\x87\x49\xa2\xa2\x9f\x78\xce\xba\x2b\x62\x44\x3d\x3c\x10\xd4\xf0\x9f\xa8\x89\xdf\x31\xd1\x7e\xb4\x95\xd9\xa3\xaa\x81\xaa\x2e\x8e\x55\xcc\x62\xf8\x37\xa7\xde\x8f\xc2\xcc\xcb\xc2\xcc\x89\x8a\x49\xed\xa2\x0e\x8e\xa5\x49\xde\x6a\x4f\x17\x72\x25\xb8\xa1\x7b\x0f\xca\x4f\x22\x64\x0c\x15\x44\xeb\xd2\x72\x50\xba\x97\x14\x1e\xf3\x82\x17\x64\x0e\xcd\x13\x71\xa8\xab\x82\x7e\x36\x45\xa7\xe4\x82\x7a\x36\x1b\x87\x60\xe6\xeb\xb0\x7d\x58\xfa\xd6\xad\xd7\x59\x4b\x55\xb9\xc6\x00\x5c\xeb\x98\x88\xf8\x17\xc7\x35\xff\x8f\x7f\x65\xd3\x07\xa7\x1e\x87\xc2\x15\xe1\x7e\x29\x74\x2d\xfe\x32\xd5\xb6\x98\x57\xc3\x86\x4b\x31\xa4\xf7\x52\xe0\x41\x88\x6f\xf1\x6b\xe6\x98\x1e\x9f\x39\xc2\x56\x24\x2c\x57\x11\x19\x89\xe6\x02\x0c\x0c\xa4\x22\x6c\x88\xf6\x0f\x89\x8f\xd8\xb3\xb6\x4f\xf0\x9e\x0e\x2d\x91\x18\x96\xdb\xff\x3b\xf2\x8d\x8f\x51\xd9\xaf\xa3\x83\x20\xa9\x09\x42\x7c\xae\xfa\x70\x28\x1d\xf2\xd4\x92\xb2\xfc\x2a\x6d\xe4\x6d\x47\x2e\x81\x46\xc9\x2a\xeb\x67\x1c\x8d\xa7\xd9\xcf\x2e\x2a\xcb\x44\x7c\x91\x89\xd9\x5e\x60\x10\x4a\xf4\x17\x98\xc7\x56\x98\x71\x48\x75\x78\xb9\xba\x4b\xd9\x02\x3b\xd8\x57\x45\x1d\x9e\x8b\x5f\xfa\xe9\x4f\xe5\xd4\xbc\xfe\x27\xe6\x49\xd1\xba\x5f\x05\x87\xc2\x43\x6b\x61\xaa\x3f\x7c\x85\x28\x97\x45\x3e\x3a\x02\x07\xa5\x29\x30\xda\xcf\x25\x66\x53\x98\x26\x14\x8a\x94\x84\xe3\x85\xeb\x2b\xef\x68\x08\x6a\x1b\x13\xb7\x7a\x5a\x01\x3d\xc7\x8b\x1d\x65\x45\x8e\xe8\x71\x3a\x95\x80\x69\x14\x8e\x6d\x0b\x60\x2c\x83\x81\x2e\xfa\xa5\x99\xa2\x4b\xad\x55\x95\x75\xa0\xbf\xa5\x96\x7a\xee\x15\xe2\x1e\x62\x6a\x8e\x65\x73\x0a\x96\xe8\x3e\x43\x9f\x02\x68\x4f\xa7\x44\x58\x47\x91\x48\xcf\x00\xcd\x76\x58\x52\x3c\xcb\xc4\x69\x15\xb1\x62\x50\x41\x9a\xaf\x24\x1d\x90\x99\x00\x49\xbc\x2e\x1d\x01\x79\xe2\xd7\x72\x02\x73\xc5\xb0\x05\x90\x1d\x3c\x40\x1c\x15\xbe\xd4\xba\x4b\x6f\xe4\x64\x0d\xe8\x8d\x1f\x19\xfc\xca\x72\xe6\x81\xe3\xb8\x3c\x52\x92\x17\x2b\x30\xd0\xe7\x73\x93\x1f\x9c\x4a\x7a\xa4\xf8\xab\xe7\xb6\x4d\x0e\xfe\x55\x87\xd5\xa3\x41\xad\xce\xeb\x46\x9d\x66\xe1\x98\xd9\xf4\xf3\x2d\xdb\x6b\x10\xd9\x25\xe8\x61\xc6\xb5\x95\x39\x81\x0e\xb7\x99\xd2\x1a\x77\x85\x5a\x19\x14\x8f\xf7\xd5\x03\x34\x48\x08\xf4\x09\xd4\x92\x74\x70\x90\xec\x09\xad\x48\x39\x73\x88\xc5\x11\xcd\xda\x97\x5f\xb0\xf0\xfb\x67\x76\x40\xdf\xc8\xd4\x60\xa4\xcd\xe5\x66\xf2\x6d\x67\x1c\x3f\x37\x22\x2b\x33\xba\x52\x5f\xd9\x33\xce\x9b\x02\x41\xc5\x14\xb8\x6a\x9a\xda\xe8\xf8\x18\x96\xee\x40\x01\x87\xab\xd8\x12\x53\x48\x0f\x8a\xd3\x8b\x26\x83\xb0\xce\xa0\x0d\xcf\x1a\x83\x13\x67\xb5\xce\x5e\xa7\x34\x83\x41\x94\x30\xf7\x3b\xc3\x37\x85\x87\x3a\xe5\x34\x2e\x72\x8a\x7b\xb7\x26\x4a\xaf\x86\x50\x33\x98\x77\x23\xc3\x50\x40\x48\xee\xf1\x1d\xbb\x7a\xd4\x25\xb9\x27\xe7\xb6\x1f\x35\x4f\x22\xfc\x5a\xbf\xb2\x2f\xc7\x16\xb2\xe5\x0c\x3e\xaf\xc7\xff\xae\x9e\xb7\x2f\xd2\x4d\xa9\x6a\xec\xe1\x07\x69\xd2\xc1\x77\x9d\x28\x40\xe0\xfe\xe7\x59\xe3\x17\x2e\x2f\xa9\xf8\x66\x9e\x75\xc6\xfc\x5d\x42\x45\x1a\xb5\x83\x50\x54\xd8\x42\x0c\xc9\x3d\xb3\x3b\x28\x07\xf9\x4d\xbe\xde\xf8\x14\x71\xac\x43\x28\xdc\xfd\x93\x80\xf3\xf2\xf8\xfe\x0d\xff\x65\xc2\xc6\x58\x83\x53\x48\x92\x76\x1a\xc5\x0d\x2e\x56\x42\x0f\xa7\x4f\xaa\xdc\x83\x68\x83\xfb\x6f\x2e\x4c\xfd\x67\x96\x63\x6a\x56\x77\x72\xc6\x8c\x2e\x25\x87\xf3\xb5\xfb\x9d\x37\xd5\xb9\x75\x65\x95\xd0\x7d\xa0\xc9\x16\x51\xfc\xc0\xc6\xcd\xfd\x0d\x68\x67\xc3\xb5\x4c\xd5\x9a\xa5\xd7\x6f\x6a\xda\x53\x49\x15\x26\x41\x4c\x53\xae\xc7\x92\xa8\xdc\xba\xda\xb5\x7c\x49\x9c\xe3\xa3\x00\x03\xc2\xde\x39\xf5\x5e\x38\x76\xff\xdd\xb5\x85\x50\xf7\xae\xf6\x6a\xb3\xa5\xb3\x3c\x41\x5f\x42\x34\x84\x64\x7b\xa5\xde\xbd\x50\x47\xe1\x1d\xf3\xea\xad\xc6\xa8\x56\x03\x89\x01\x3a\x0a\x90\xb5\x14\x5a\xda\x88\xd4\xd6\x0b\x81\x2f\x96\x2c\x5b\x57\xa0\x46\x55\x58\x0c\x12\xa7\xbe\x1a\xde\xb7\x9f\x88\xe7\x72\x9c\x32\x4b\xdb\x4a\xb5\x4c\xef\x0f\x3b\x16\x89\xd7\x71\xbf\xba\xd0\xe6\x87\xa8\x9e\x70\x75\xdc\x49\xf1\x84\x5b\xeb\xc2\x55\x10\x42\x22\xa7\x55\x6c\xa7\x32\xf3\x62\xcb\x0a\x8f\x09\x6f\x0a\xbe\x04\xc5\x0e\x0c\x71\x28\xf8\x63\x2a\xea\x7e\xf8\x6d\x9a\x7e\xcc\xe7\x93\xb9\x88\x94\x9c\xa1\xb5\x80\xb9\x99\x8b\x92\x6b\xae\x0b\x25\xf7\x74\xc1\xdc\x72\x0f\x12\x49\x34\x20\x2e\x4f\x24\x43\xb5\x13\x7f\x36\xa8\x17\x02\x68\x17\xd8\x5d\x9a\x0a\x77\xb9\x07\x4a\xba\xec\x8f\xd2\x84\x8d\x5b\xa8\xf5\x58\xcd\x65\x00\xf1\x77\x38\x4b\x96\x2d\x98\x2f\xbf\x36\xfb\x4b\xbf\x61\x56\x80\xa6\x45\xcd\x2c\xf1\xe3\x24\x72\x48\xed\xf7\x6c\xb3\xab\x3a\xf9\x6e\xc4\xfc\x85\x68\xc8\xef\x91\x54\x49\x45\x96\x20\x57\x49\x89\xad\x11\x45\x4b\x02\x9b\xdb\xd5\xc1\x16\xcd\xd1\x65\x28\x5b\x18\x95\x20\x3a\x23\x5c\xc0\x92\x37\xf8\xe7\x8e\x92\x4e\x81\xa4\x55\xd1\x7a\x8b\xaf\x55\xcd\x5e\x4f\xe7\xf4\x5d\x62\xf7\x09\x30\x48\xa2\x63\x1d\x90\xd6\x32\xf3\x1a\x04\x42\xee\x70\xda\x0b\x37\x39\x84\x72\xac\x50\x37\xee\xd8\x9f\xed\xab\x5f\x0a\xa6\x9a\x8d\xf0\xe4\x9b\x07\xc1\x19\x2d\xd8\x6f\x7d\x0f\x3f\x0f\x5b\x6f\xd7\xb4\xfd\xd1\x4a\xb3\x29\x35\x6a\xab\x40\xcf\x23\x40\x15\xb9\xe3\x89\xf2\x60\x1c\xc3\x70\x3f\xe0\x11\x47\x21\xcd\xa1\x84\xcc\x70\xe8\x66\xe9\x71\x5d\x97\x2b\xad\x8a\xd5\xb7\x82\x1a\x3a\x16\xed\x32\x64\x4a\x8b\x1f\x84\x08\xef\xb8\x69\xe4\x48\xc2\xa8\xc5\x75\x94\xd7\x32\xb5\x2a\x11\x2f\x27\xe9\x30\x9a\xde\xc0\x43\x5d\x23\x95\x23\x46\x26\x52\x02\x1e\x44\xc2\x33\x3c\x0d\x49\xb5\x80\x42\xe7\xba\x49\xd2\x05\xd3\x27\x02\x93\x9c\xac\x38\xa5\xb6\xac\xa0\x5f\xf2\x3c\x5b\x1b\x59\x95\xae\x67\x77\x64\xed\x20\x65\xa9\xb0\x2a\x3b\x6d\x9a\xff\x1f\x9f\xe6\x0f\x63\xa8\xa1\x76\x70\x54\xbf\x53\xfa\x8d\xf9\x00\x0e\xd5\xec\xb2\x83\x70\x6e\x4b\xe3\xf5\x0e\xfc\xfc\xfc\x0c\x67\x2e\x2a\x69\xeb\xa4\x60\x61\xa3\xa9\x72\x2a\xfe\xa0\x41\x6e\x34\x4b\x1f\xcf\xb3\x9e\x43\x80\x57\x08\xe9\x07\x27\x27\x79\x54\x1a\x3f\x0a\xb9\x6d\x8f\xa3\xce\x18\x3a\x72\x13\x4b\x52\x31\x78\x63\x82\x6c\x79\x7f\x8c\x02\xb5\x43\xcb\x5b\x0d\x66\xb5\x7c\x42\xfa\xe4\x2a\xcb\xe3\xba\x1f\xd0\xf7\x93\x9b\x60\x3f\x41\xe1\x6e\xbb\x63\x8b\xfc\x8b\xc2\xeb\x3e\x25\x88\x8e\x9a\x96\x7d\x68\x62\xd7\xa7\xd4\xd6\xba\x1c\xa1\xb2\x83\x1d\x32\x74\xf8\x03\x18\x12\x6f\x24\x8e\x2e\xf6\x68\xc7\xbb\xc7\xe9\x6d\xcc\xe8\x6e\x0c\xbb\x08\xec\xb7\x8c\x0e\x18\x70\xa9\x58\x84\xff\x0e\x32\xfe\x0f\x0b\xd3\x85\x7a\x46\x58\x58\x0c\xbc\x34\x58\x5b\x29\xa0\x15\xc0\xa3\xc8\x61\x5a\xf0\xf4\x24\x9b\x82\xd3\x97\x42\x60\xda\xf9\x9f\x72\x28\x79\x08\x4b\xbd\xe2\x5b\x62\x8f\xb8\x71\x17\x00\x33\x11\xea\xa4\x39\x02\xca\x0f\x28\x6f\xda\x29\x48\x90\x0d\x1d\xc2\x6c\xa1\xf1\xb6\x0c\x10\x81\x0f\x07\x59\x6a\xf7\xe4\x34\x73\x23\x29\x2e\xc7\xe9\x08\x6f\x80\xef\x56\x30\x85\xea\x2d\xe8\xc2\x0d\xa7\xcc\xc1\x59\x8e\xff\xa0\x2f\xfa\xbc\x20\x51\xc3\x64\x3f\xfa\x84\x88\xbb\x68\x70\x84\x26\x35\xbb\x89\xe0\x20\x7c\xb8\x75\x93\x7f\x16\x6c\x87\xe4\x11\x1d\xab\x6e\xa5\x48\x1d\x68\x23\xda\xa3\x08\xde\xfd\xc3\xff\xec\x27\xa3\x01\xa0\xd9\x9b\xae\xe3\xc9\xdd\xd7\x4a\x61\x2a\xe7\x67\x31\x3a\x2f\x26\xd6\x14\x9d\x59\x28\xd1\xa1\xfd\x84\xb8\x9e\x8a\xc1\x22\xc4\x83\xea\xa5\x1f\x77\xef\x8b\xe5\xbb\xdf\x37\x02\x90\x94\xb9\xc8\x40\x06\xbd\x3e\x8e\x8f\x3c\xa1\xec\x32\xf9\x74\x94\xcf\x19\x2a\xef\x89\x8a\x5a\x2d\xa1\xc4\x81\xe9\x25\x37\x12\xc1\x3f\xae\x8b\xe6\x08\x7f\x68\x63\xe4\xbc\x9f\x44\x0f\xe0\xdb\x4a\xd6\x0e\x71\x90\x39\xa6\x0b\x60\x49\x8e\x40\x03\x1a\xfe\xff\x6e\x41\x59\x32\x9e\xcd\xb7\x8b\x46\xb2\x85\x33\x83\x62\xc5\x0d\x81\xf0\xf0\xca\x3d\x6b\x6b\xce\x21\x2c\xb0\x07\x68\x6f\x45\xc2\x1e\xd0\x9b\x4b\x5e\xa7\x9b\x06\x33\x03\x86\x24\xed\xde\xec\x42\x74\x6d\xe5\xb7\x39\x39\x3d\x30\xc6\xd0\x18\x4b\xe5\x35\x83\xa2\xfe\x8f\xfb\xf7\x0c\xa1\x73\x14\x25\x82\xfd\xbe\xed\xe1\xae\x40\x9f\x71\x48\xad\xf8\x90\xd6\x31\x47\xfd\x73\x94\xb9\x42\xdd\x06\x23\x3f\xcc\x38\xd6\x78\x42\x5d\xbc\x57\xef\x18\x1b\x42\x81\x4f\x4e\xd4\x16\xcf\x88\xbe\xa2\xe6\x94\x4a\xa7\x4a\xc3\x2f\x00\x34\xf5\x24\x5d\x11\xfc\x5f\x24\x79\xe1\x9e\xc5\xb6\x1a\x35\x1a\x9c\x4b\x1e\xc0\x88\xb0\xed\x5d\xbd\x82\x32\xce\x44\x1d\x16\x7f\xef\x81\x92\xb3\xd4\x49\x58\x1c\x9c\xdf\xb8\x41\x8f\x4c\x3f\x30\x89\x81\x83\xce\xe9\xb1\x00\x20\x93\xe2\x23\x95\x52\x6f\xb0\x5d\x70\x13\xb9\x04\x5e\x2e\x2a\x5b\x1e\x17\x1a\x9d\x21\x7b\x4d\x87\x99\xc2\x5f\xfa\xe9\xe2\xec\x1e\x32\xb3\xb6\xf9\xe4\xcc\xe6\x5a\x4a\xa5\x97\xbd\xe0\xa8\xe8\x2b\x9c\xcd\x1f\x55\x81\x9c\x1e\x53\x6b\xb7\x0c\x93\x7d\x99\xc2\xaf\x06\x07\x6d\x22\x8d\xcf\xe5\xbd\x37\xb9\x68\xf6\xc8\x65\xbd\xec\x96\x05\xe3\xd6\x75\x73\x3a\xfb\x25\x1b\xd8\xda\x78\x2b\x68\x88\x74\xbb\xe2\xd4\xad\x67\xb1\x92\xbc\xbe\x80\x9d\x2d\x27\x1e\x78\x30\xd4\x81\x95\x67\x68\xa3\x01\xdd\xdd\x08\xbe\x82\x97\x4f\xef\x0d\xbf\x9d\x7b\x5a\x74\x44\x7c\x84\xc5\xea\x92\x0c\xb9\x03\xc0\x38\x86\xce\xe7\x40\x98\xa1\xaf\xaf\x4b\xcd\xf9\x14\x75\xa6\xe5\x62\x85\x78\x31\xcf\x95\xe3\xdd\x77\x2d\xe0\x8d\xab\x62\x06\x47\x22\xe5\xb3\x1d\x00\xbc\x08\xe4\x8d\x72\xea\x7a\xbe\x8a\xd7\xf8\x1a\x0d\xe2\x77\xc9\xc1\x7d\x0e\x2d\x23\xae\xb4\x32\x0b\x55\xb6\x84\x2a\xe8\xc3\x66\x92\x82\x47\x9b\xb6\x20\xb5\x7d\x67\xdb\xcf\xdf\xdc\x74\x5f\x38\xee\x31\xca\x01\x07\x22\x0e\xbb\x6d\x4a\x42\x5c\xed\x4f\xe8\xc2\xd8\x2f\x13\x15\x34\xb0\xd2\x49\xa0\xbb\x7f\x99\x66\xa5\x85', 2)

# cleanup
del pyarmor_runtime

